@@ -17,21 +17,27 @@ class Metric(Artifact):
                  aim_session_id: Optional[int] = None,
                  **kwargs):
         if not self.validate_name(str(name)):
-            raise ValueError('Metric name can contain only letters, numbers, ' +
-                             'underscore, dash and space`')
+            raise ValueError('metric name can contain only letters, numbers, ' +
+                             'underscore, dash and space')
 
         if not isinstance(value, (int, float)):
-            raise TypeError('Metric value must be a type of int or float')
+            raise TypeError('metric value must be a type of int or float')
 
         self.name = re.sub(' +', ' ', str(name))
         self.value = value
         self.epoch = epoch
-        self.context = kwargs if len(kwargs.keys()) else None
+
+        if len(kwargs.keys()):
+            self.context = kwargs
+            self.hashable_context = tuple(sorted(kwargs.items()))
+        else:
+            self.context = None
+            self.hashable_context = None
 
         super(Metric, self).__init__(self.cat)
 
         if self.context is not None:
-            step_meta = tuple(sorted(self.context.items()))
+            step_meta = self.hashable_context
         else:
             step_meta = None
         self.initialize_step_counter(step, self.name, step_meta,
