@@ -4,19 +4,21 @@ from typing import Optional, Dict, List
 
 from aim.engine.repo import AimRepo
 from aim.artifacts.artifact_writer import ArtifactWriter
-from aim.sdk.session.utils import set_automated_env_vars
+from aim.sdk.session.utils import exception_resistant
 from aim.artifacts import *
 from aim.engine.configs import (
     AIM_BRANCH_ENV_VAR,
     AIM_COMMIT_ENV_VAR,
     AIM_AUTOMATED_EXEC_ENV_VAR,
     AIM_DEFAULT_BRANCH_NAME,
+    AIM_MAP_METRICS_KEYWORD,
 )
 
 
 class Session:
     sessions: Dict[str, List['Session']] = {}
 
+    @exception_resistant
     def __init__(self, repo: Optional[str] = None,
                  experiment: Optional[str] = None):
         self.active = False
@@ -28,18 +30,24 @@ class Session:
 
         # Start a new run
         self.repo.commit_init()
+        self.metrics = {}
 
         self.active = True
 
         # Finalize run
         atexit.register(self.close)
 
+    @exception_resistant
     def __del__(self):
         self.close()
 
+    @exception_resistant
     def close(self):
         if self.active:
             self.active = False
+            # Set metrics
+            self.set_params(self.metrics, name=AIM_MAP_METRICS_KEYWORD)
+
             self.repo.close_records_storage()
             self.repo.commit_finish()
 
@@ -49,6 +57,7 @@ class Session:
                 if len(Session.sessions[self.repo.path]) == 0:
                     del Session.sessions[self.repo.path]
 
+    @exception_resistant
     def track(self, *args, **kwargs):
         if self.repo is None:
             raise FileNotFoundError('Aim repository was not found')
@@ -56,7 +65,7 @@ class Session:
         artifact_name = None
 
         if not len(args):
-            print('Artifact is not specified')
+            raise TypeError('artifact name is not specified')
 
         if isinstance(args[0], str):
             artifact_name = args[0]
@@ -71,9 +80,11 @@ class Session:
             kwargs['value'] = args[0]
             args = []
 
-        if artifact_name is None or artifact_name not in globals():
-            print('Aim cannot track: \'{0}\''.format(artifact_name))
-            return
+        if artifact_name is None:
+            raise TypeError('artifact name is not specified')
+
+        if artifact_name not in globals():
+            raise TypeError('Aim cannot track: \'{}\''.format(artifact_name))
 
         # Get corresponding class
         obj = globals()[artifact_name]
@@ -81,15 +92,38 @@ class Session:
         # Create an instance
         inst = obj(*args, **kwargs, aim_session_id=id(self))
 
+        # Collect metrics values
+        if isinstance(inst, Metric):
+            self.metrics.setdefault(inst.name, [])
+            for metric_item in self.metrics[inst.name]:
+                if metric_item['context'] == inst.hashable_context:
+                    if inst.value < metric_item['values']['min']:
+                        metric_item['values']['min'] = inst.value
+                    if inst.value > metric_item['values']['max']:
+                        metric_item['values']['max'] = inst.value
+                    metric_item['values']['last'] = inst.value
+                    break
+            else:
+                self.metrics[inst.name].append({
+                    'context': inst.hashable_context,
+                    'values': {
+                        'min': inst.value,
+                        'max': inst.value,
+                        'last': inst.value,
+                    },
+                })
+
         writer = ArtifactWriter()
         writer.save(self.repo, inst)
 
         return inst
 
+    @exception_resistant
     def set_params(self, params: dict, name: Optional[str] = None):
         return self.track(params, namespace=name)
 
     @staticmethod
+    @exception_resistant
     def get_repo(path: Optional[str] = None,
                  experiment_name: Optional[str] = None) -> AimRepo:
         # Auto commit
